@@ -9,12 +9,14 @@ class SendType(Enum):
     RELAY = 2
 
 def send_packet( packet_type, ctx, datas=[]):
+    _initThread()
     global q
     if q.full():
         return
     q.put((SendType.DATAS, (packet_type, ctx, datas)))
 
 def send_relaypack( packbytes):
+    _initThread()
     global q
     if q.full():
         return
@@ -39,4 +41,21 @@ def startWhatapThread():
     t.setDaemon(True)
     t.start()
 
-startWhatapThread()
\ No newline at end of file
+_lock = threading.Lock()
+_initialized = False
+
+def _initThread():
+    global _lock, _initialized
+    if _initialized:
+        return
+    try:
+        if _initialized:
+            return
+        _lock.acquire()
+        if _initialized:
+            return
+        _initialized=True
+        startWhatapThread()
+    finally:
+        _lock.release()
+
