@@ -28,7 +28,7 @@ def startWhatapThread():
                     time.sleep(0.05)
 
     t = threading.Thread(target=__whatap_jobs)
-    t.setDaemon(True)
+    t.daemon = True
     t.start()
 
 
@@ -41,7 +41,7 @@ def startWhatapThread():
                 debug_util.printAllStack()
             time.sleep(10)
     t = threading.Thread(target=__debug)
-    t.setDaemon(True)
+    t.daemon = True
     t.start()
 
 
