@@ -143,7 +143,7 @@ def interceptor_error_log(trxid, e, fn, args, kwargs):
     bout.writePack(p, None)
     packbytes = bout.toByteArray()
     
-    UdpSession.send_relaypack(packbytes)
+    async_sender.send_relaypack(packbytes)
 
 def interceptor(fn, dependant, *args, **kwargs):
     if not hasattr(dependant, _WHATAP_DICT):
