@@ -2,7 +2,7 @@ from whatap.trace import get_dict
 from whatap.trace.mod.application_wsgi import trace_handler, \
     interceptor_step_error
 from whatap.trace.trace_context_manager import TraceContextManager
-from whatap.net.udp_session import UdpSession
+import whatap.net.async_sender as async_sender
 from whatap.net.packet_type_enum import PacketTypeEnum
 from whatap.util.date_util import DateUtil
 import numbers
@@ -27,7 +27,7 @@ def intercept_send_command(fn, instance, *args, **kwargs):
     ctx.db_opening = True
     datas = [text]
     ctx.elapsed = DateUtil.nowSystem() - start_time
-    UdpSession.send_packet(PacketTypeEnum.TX_DB_CONN, ctx, datas)
+    async_sender.send_packet(PacketTypeEnum.TX_DB_CONN, ctx, datas)
     query = " ".join([ str(arg)[:20] for arg in args])
     if ctx.active_sqlhash:
         return fn(instance, *args, **kwargs)
@@ -45,7 +45,7 @@ def intercept_send_command(fn, instance, *args, **kwargs):
         ctx.db_opening = False
         datas = [ctx.lctx.get('dbc', ''), query]
         ctx.elapsed = DateUtil.nowSystem() - start_time
-        UdpSession.send_packet(PacketTypeEnum.TX_SQL, ctx,
+        async_sender.send_packet(PacketTypeEnum.TX_SQL, ctx,
                                datas)
 
 
@@ -74,7 +74,7 @@ def interceptor_read_response(fn, *args, **kwargs):
                 msg = '{0}: {1}'.format('Fetch bytes', count)
                 datas = [ msg,' ', ' ']
                 ctx.elapsed = 0
-                UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
+                async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
 
         ctx.active_sqlhash = 0
 
