@@ -1,5 +1,5 @@
 from whatap.net.packet_type_enum import PacketTypeEnum
-from whatap.net.udp_session import UdpSession
+import whatap.net.async_sender as async_sender
 from whatap.trace.mod.application_wsgi import trace_handler, interceptor_db_execute, interceptor_step_error, sendDebugProfile
 from whatap.util.date_util import DateUtil
 from whatap.trace.trace_context_manager import TraceContextManager
@@ -19,7 +19,7 @@ def instrument_sqlalchemy(module):
             
             datas = [' ', ' ', 'DB SESSION INFO: ' + text]
             ctx.elapsed = DateUtil.nowSystem() - start_time
-            UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
+            async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
             
             callback = fn(*args, **kwargs)
             return callback
@@ -88,7 +88,7 @@ def instrument_sqlalchemy_engine(module):
                     datas = [ctx.lctx.get('dbc', ''), query]
                     ctx.elapsed = DateUtil.nowSystem() - start_time
                     # print('instrument_sqlalchemy_engine 6.1', datas)
-                    UdpSession.send_packet(PacketTypeEnum.TX_SQL, ctx,
+                    async_sender.send_packet(PacketTypeEnum.TX_SQL, ctx,
                                            datas)
                     # print('instrument_sqlalchemy_engine 7')
                     if hasattr(cursor, 'rowcount'):
@@ -98,7 +98,7 @@ def instrument_sqlalchemy_engine(module):
                             desc = '{0}: {1}'.format('Fetch count', count)
                             datas = [' ', ' ', desc]
                             ctx.elapsed = 0
-                            UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
+                            async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
                     ctx.active_sqlhash = 0
 
                 # print('instrument_sqlalchemy_engine 9')
